==> kjy-base-api-0.0.21-web-dugq5-20210331.141628-1-sources.jar: cn/com/duiba/kjy/base/customweb/web/filter/KjjAccessLogFilter.java <==
package cn.com.duiba.kjy.base.customweb.web.filter;

import cn.com.duiba.kjy.base.customweb.util.PerfTestUtil;
import cn.com.duiba.kjy.base.customweb.web.bean.KjjHttpRequest;
import cn.com.duiba.kjy.base.customweb.web.bean.KjjHttpResponse;
import cn.com.duibaboot.ext.autoconfigure.accesslog.AbstractAccessLogFilter;
import io.netty.handler.codec.http.cookie.Cookie;
import io.netty.handler.codec.http.cookie.DefaultCookie;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * @author dugq
 * @date 2021/3/30 5:53 下午
 */
@Slf4j
public class KjjAccessLogFilter extends AbstractAccessLogFilter<KjjHttpRequest,KjjHttpResponse> implements CustomFilter{

    @Override
    public void doFilter(CustomFilterChain customFilterChain, KjjHttpRequest httpRequest, KjjHttpResponse response) throws Throwable {
        long start = System.currentTimeMillis();
        try {
            doBefore(httpRequest, response);
            customFilterChain.filter(httpRequest, response);
        }finally {
            doAfter(httpRequest, response, System.currentTimeMillis() - start);
        }
    }

    @Override
    protected String getRequestURI(KjjHttpRequest req) {
        return req.getRequestURI();
    }

    @Override
    protected String getMethod(KjjHttpRequest req) {
        return req.getMethod();
    }

    @Override
    protected String getQueryString(KjjHttpRequest req) {
        return req.getQueryString();
    }

    @Override
    protected String getHeader(KjjHttpRequest req, String key) {
        return req.getHeader(key);
    }

    @Override
    protected String getIpAddr(KjjHttpRequest req) {
        return req.getIpAddr();
    }

    @Override
    protected boolean isPerfTestRequest(KjjHttpRequest req) {
        return PerfTestUtil.isPerfTestRequest(req);
    }

    @Override
    protected void addAttribute(KjjHttpRequest req, String key, Object value) {
        req.addAttribute(key,value);
    }

    @Override
    protected Object getAttribute(KjjHttpRequest req, String key) {
        return req.getAttribute(key);
    }

    @Override
    protected String getParameter(KjjHttpRequest req, String key) {
        return req.getParameter(key);
    }

    @Override
    protected List<String> getParameterNames(KjjHttpRequest req) {
        return new ArrayList<>(req.getParamMap().keySet());
    }

    @Override
    protected int getStatus(KjjHttpResponse resp) {
        return resp.getResponse().status().code();
    }

    @Override
    protected void addCookie(KjjHttpResponse resp, String key, String value, String domain, String path) {
        Cookie cookie = new DefaultCookie(key, value);
        if(domain != null){
            cookie.setDomain(domain);
        }
        if (path != null) {
            cookie.setPath(path);
        }
        resp.addCookie(cookie);
    }

    @Override
    protected Map<String, String> getCookieMap(KjjHttpRequest req) {
       return req.getCookies().stream().collect(Collectors.toMap(Cookie::name,Cookie::value,(left,right)->left));
    }

    @Override
    protected void ensureSafeCall() {
        String threadName = StringUtils.defaultString(Thread.currentThread().getName());
        if (!threadName.startsWith("netty")){
            log.error("can not use accessLogger out of netty work thread!");
        }
    }
}

==> kjy-base-api-0.0.23-web-dugq-20-20210414.055102-2-sources.jar: cn/com/duiba/kjy/base/customweb/web/filter/KjjAccessLogFilter.java <==
package cn.com.duiba.kjy.base.customweb.web.filter;

import cn.com.duiba.kjy.base.customweb.util.PerfTestUtil;
import cn.com.duiba.kjy.base.customweb.web.bean.KjjHttpRequest;
import cn.com.duiba.kjy.base.customweb.web.bean.KjjHttpResponse;
import cn.com.duibaboot.ext.autoconfigure.accesslog.AbstractAccessLogFilter;
import io.netty.handler.codec.http.cookie.Cookie;
import io.netty.handler.codec.http.cookie.DefaultCookie;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.util.StopWatch;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.concurrent.atomic.AtomicInteger;
import java.util.concurrent.atomic.AtomicLong;
import java.util.stream.Collectors;

/**
 * @author dugq
 * @date 2021/3/30 5:53 下午
 */
@Slf4j
public class KjjAccessLogFilter extends AbstractAccessLogFilter<KjjHttpRequest,KjjHttpResponse> implements CustomFilter{

    public static final AtomicInteger count = new AtomicInteger(0);
    public static final AtomicLong beforeTime = new AtomicLong(0);
    public static final AtomicLong afterTime = new AtomicLong(0);

    @Override
    public void doFilter(CustomFilterChain customFilterChain, KjjHttpRequest httpRequest, KjjHttpResponse response) throws Throwable {
        long start = System.currentTimeMillis();
        try {
            StopWatch stopWatch = new StopWatch();
            stopWatch.start();
            doBefore(httpRequest, response);
            stopWatch.stop();
            final long totalTimeNanos = stopWatch.getTotalTimeNanos();
            beforeTime.addAndGet(totalTimeNanos);
            customFilterChain.filter(httpRequest, response);
        }finally {
            StopWatch stopWatch1 = new StopWatch();
            stopWatch1.start();
            doAfter(httpRequest, response, System.currentTimeMillis() - start);
            stopWatch1.stop();
            final long totalTimeNanos = stopWatch1.getTotalTimeNanos();
            afterTime.addAndGet(totalTimeNanos);
            count.incrementAndGet();
        }
    }

    @Override
    protected String getRequestURI(KjjHttpRequest req) {
        return req.getRequestURI();
    }

    @Override
    protected String getMethod(KjjHttpRequest req) {
        return req.getMethod();
    }

    @Override
    protected String getQueryString(KjjHttpRequest req) {
        return req.getQueryString();
    }

    @Override
    protected String getHeader(KjjHttpRequest req, String key) {
        return req.getHeader(key);
    }

    @Override
    protected String getIpAddr(KjjHttpRequest req) {
        return req.getIpAddr();
    }

    @Override
    protected boolean isPerfTestRequest(KjjHttpRequest req) {
        return PerfTestUtil.isPerfTestRequest(req);
    }

    @Override
    protected void addAttribute(KjjHttpRequest req, String key, Object value) {
        req.addAttribute(key,value);
    }

    @Override
    protected Object getAttribute(KjjHttpRequest req, String key) {
        return req.getAttribute(key);
    }

    @Override
    protected String getParameter(KjjHttpRequest req, String key) {
        return req.getParameter(key);
    }

    @Override
    protected List<String> getParameterNames(KjjHttpRequest req) {
        return new ArrayList<>(req.getParamMap().keySet());
    }

    @Override
    protected int getStatus(KjjHttpResponse resp) {
        return resp.getResponse().status().code();
    }

    @Override
    protected void addCookie(KjjHttpResponse resp, String key, String value, String domain, String path) {
        Cookie cookie = new DefaultCookie(key, value);
        if(domain != null){
            cookie.setDomain(domain);
        }
        if (path != null) {
            cookie.setPath(path);
        }
        resp.addCookie(cookie);
    }

    @Override
    protected Map<String, String> getCookieMap(KjjHttpRequest req) {
       return req.getCookies().stream().collect(Collectors.toMap(Cookie::name,Cookie::value,(left,right)->left));
    }

    @Override
    protected void ensureSafeCall() {
        String threadName = StringUtils.defaultString(Thread.currentThread().getName());
        if (!threadName.startsWith("netty")){
            log.error("can not use accessLogger out of netty work thread!");
        }
    }
}
